use phf::phf_map;

#[derive(Debug)]
pub struct InstallInfo {
    pub url: &'static str,
    pub files: &'static [&'static str],
}

static LANGUAGES: phf::Map<&'static str, InstallInfo> = phf_map! {
    "dockerfile" => InstallInfo{
        url: "https://github.com/camdencheek/tree-sitter-dockerfile",
        files: &["src/parser.c", "src/scanner.c"],
    },
    "ini" => InstallInfo{
        url: "https://github.com/justinmk/tree-sitter-ini",
        files: &["src/parser.c"],
    },
    "tcl" => InstallInfo{
        url: "https://github.com/tree-sitter-grammars/tree-sitter-tcl",
        files: &["src/parser.c", "src/scanner.c"],
    },
    "yaml" => InstallInfo{
        url: "https://github.com/tree-sitter-grammars/tree-sitter-yaml",
        files: &["src/parser.c", "src/scanner.c"],
    },
    "zig" => InstallInfo{
        url: "https://github.com/tree-sitter-grammars/tree-sitter-zig",
        files: &["src/parser.c"],
    },
};

pub fn get_install_info(language: &str) -> Option<&InstallInfo> {
    LANGUAGES.get(language)
}
